@@ -18,6 +18,7 @@ typedef struct {
     PyObject_HEAD
     Runtime* rt;
     PyObject* global;
+    PyObject* access;
     JSContext* cx;
     JSObject* root;
     PyDictObject* classes;
@@ -31,6 +32,8 @@ typedef struct {
 PyObject* Context_get_class(Context* cx, const char* key);
 int Context_add_class(Context* cx, const char* key, PyObject* val);
 
+int Context_has_access(Context*, JSContext*, PyObject*, PyObject*);
+
 int Context_has_object(Context* cx, PyObject* val);
 int Context_add_object(Context* cx, PyObject* val);
 int Context_rem_object(Context* cx, PyObject* val);
